@@ -172,7 +172,8 @@ class Bubble(BaseModel):
             base_wait_time: Optional[Annotated[int, Field(ge=MIN_WAIT_TIME)]] = None,
             exponential_backoff: Optional[bool] = None,
             verbose_level: Optional[Annotated[int, Field(ge=MIN_VERB_LEV, le=MAX_VERB_LEV)]] = None,
-            timeout: Optional[Annotated[int, Field(ge=0)]] = None
+            timeout: Optional[Annotated[int, Field(ge=0)]] = None,
+            exclude_remaining: Optional[bool] = False
     ) -> GetDataResp:
         """
         This function is used to make GET requests to Bubble and handle errors and retries.
@@ -197,6 +198,7 @@ class Bubble(BaseModel):
         If None, use self.verbose_level
         :param timeout: Overrides parent value. Use this parameter to set request timeout in seconds. Set 0 to remove
         timeout. (!) None will not erase the parent value (!).
+        :param exclude_remaining: If set to True, remaining is an estimation and not the exact count
         If None, use self.timeout
         """
         if n_retries is None:
@@ -229,17 +231,16 @@ class Bubble(BaseModel):
                 "cursor": cursor,
                 "constraints": json.dumps([c.dict() for c in constraints]) if constraints is not None else None,
                 "sort_field": sort_field,
-                "descending": descending
+                "descending": descending,
+                "exclude_remaining": exclude_remaining
             }
 
         if verbose_level >= 2:
             print("GET request URL : ", full_url)
+            print("GET request parameters : ", json.dumps(params, indent=4))
 
         headers = {"Authorization": f"Bearer {self.api_key}"} if self.api_key is not None else None
 
-        if verbose_level >= 2:
-            print("GET request parameters : ", json.dumps(params, indent=4))
-
         break_while = False
         retry_index = 0
         resp = None
@@ -247,7 +248,7 @@ class Bubble(BaseModel):
 
         while retry_index <= n_retries and not break_while:
             try:
-                if retry_index >= 1 or verbose_level >= 2:
+                if (retry_index >= 1 or verbose_level >= 2) and verbose_level >= 1:
                     print(f"GET request - Retry index : {retry_index}/{n_retries}")
 
                 resp = requests.get(
@@ -284,6 +285,7 @@ class Bubble(BaseModel):
                     )
 
                 elif resp.status_code in [400, 404]:
+                    break_while = True
                     if resp.status_code == 404 and unique_id is not None:
                         return GetDataResp(
                             results=[],
@@ -291,7 +293,6 @@ class Bubble(BaseModel):
                             count=0
                         )
 
-                    break_while = True
                     if verbose_level >= 1:
                         print(f"GET request - {resp.status_code} - {str(resp.content)}")
 
@@ -543,7 +544,7 @@ class Bubble(BaseModel):
                             raise ValueError(f"{file_format} is not a valid value for file_format")
 
         return GetFullDataResp(
-            results=None if path_to_file else full_results,
+            results=None if path_to_file is not None else full_results,
             path_to_file=path_to_file
         )
 
@@ -614,7 +615,8 @@ class Bubble(BaseModel):
                 base_wait_time=base_wait_time,
                 exponential_backoff=exponential_backoff,
                 verbose_level=verbose_level,
-                timeout=timeout
+                timeout=timeout,
+                exclude_remaining=False if fail_if_multiple_results else True
             )
 
         if fail_if_multiple_results and get_data_resp.remaining > 0:
@@ -679,12 +681,10 @@ class Bubble(BaseModel):
 
         if verbose_level >= 2:
             print("PATCH request URL : ", full_url)
+            print("PATCH request parameters : ", json.dumps(params, indent=4))
 
         headers = {"Authorization": f"Bearer {self.api_key}"} if self.api_key is not None else None
 
-        if verbose_level >= 2:
-            print("PATCH request parameters : ", json.dumps(params, indent=4))
-
         break_while = False
         retry_index = 0
         resp = None
@@ -692,7 +692,7 @@ class Bubble(BaseModel):
 
         while retry_index <= n_retries and not break_while:
             try:
-                if retry_index >= 1 or verbose_level >= 2:
+                if (retry_index >= 1 or verbose_level >= 2) and verbose_level >= 1:
                     print(f"PATCH request - Retry index : {retry_index}/{n_retries}")
 
                 resp = requests.patch(
@@ -838,7 +838,7 @@ class Bubble(BaseModel):
 
         while retry_index <= n_retries and not break_while:
             try:
-                if retry_index >= 1 or verbose_level >= 2:
+                if (retry_index >= 1 or verbose_level >= 2) and verbose_level >= 1:
                     print(f"POST request - Retry index : {retry_index}/{n_retries}")
 
                 resp = requests.post(
